@@ -4,13 +4,13 @@ import logging
 import platform
 import socketio
 from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription
-from aiortc.contrib.media import MediaPlayer, MediaRelay
-
+from aiortc.contrib.media import MediaPlayer, MediaRelay, MediaBlackhole
 
 pcs = set()
 relay = None
 webcam = None
 
+
 def create_local_tracks(play_from, decode, device, rtbufsize):
     global relay, webcam
 
@@ -95,6 +95,12 @@ class GSPeerConnectionBroadcasterUniversal:
                                                device=self.gsdbs.credentials["webcam"],
                                                rtbufsize=self.gsdbs.credentials["rtbufsize"])
 
+            @pc.on("track")
+            async def on_track(track):
+                if track.kind == "video":
+                    mediablackhole = MediaBlackhole()
+                    mediablackhole.addTrack(track)
+
             if video:
                 video_sender = pc.addTrack(video)
                 force_codec(pc, video_sender, "video/H264")
