@@ -22,7 +22,7 @@ class VideoTransformTrack(MediaStreamTrack):
 
     async def recv(self):
         frame = await self.track.recv()
-        self.onframe(self.gsdbs, self.source, frame)
+        await self.onframe(self.gsdbs, self.source, frame)
         return frame
 
 
